@@ -32,13 +32,16 @@ class SweepEntry(object):
 
     :param fstart: starting frequency in Hz
     :param fstop: ending frequency in Hz
-    :param shift: the frequency shift in Hz
+    :param fstep: frequency step in Hz
+    :param fshift: the frequency shift in Hz
     :param decimation: the decimation value (0 or 4 - 1023)
     :param antenna: the antenna (1 or 2)
     :param gain: the RF gain value ('high', 'medium', 'low' or 'vlow')
     :param ifgain: the IF gain in dB (-10 - 34)
     :param spp: samples per packet
     :param ppb: packets per block
+    :param dwell_s: dwell time seconds
+    :param dwell_us: dwell time microseconds
     :param trigtype: trigger type ('none' or 'level')
     :param level_fstart: level trigger starting frequency in Hz
     :param level_fstop: level trigger ending frequency in Hz
@@ -57,6 +60,8 @@ class SweepEntry(object):
             spp=1024,
             ppb=1,
             trigtype="none",
+            dwell_s=0,
+            dwell_us=0,
             level_fstart= 50000000,
             level_fstop=10000000000,
             level_amplitude=-100):
@@ -70,6 +75,8 @@ class SweepEntry(object):
         self.ifgain = ifgain
         self.spp = spp
         self.ppb = ppb
+        self.dwell_s = dwell_s
+        self.dwell_us = dwell_us
         self.trigtype = trigtype
         self.level_fstart = level_fstart
         self.level_fstop = level_fstop
@@ -87,6 +94,8 @@ class SweepEntry(object):
             + "\tgain: %s\n" % self.gain
             + "\tifgain: %d\n" % self.ifgain
             + "\tspp/ppb: %d/%d\n" % (self.spp, self.ppb)
+            + "\tdwell_s: %s\n" % self.dwell_s
+            + "\tdwell_us: %s\n" % self.dwell_us
             + "\ttrigtype: %s\n" % self.trigtype
             + "\tlevel:fstart/fstop/famplitude: %d / %d / %d\n" % (self.level_fstart, self.level_fstop, self.level_amplitude)
             + ")")
